@@ -33,7 +33,7 @@ class NullType(Type):
         raise ValueError("NullType has no values to compare")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
