@@ -243,7 +243,7 @@ class Shape_i(COp):
         return ParamsType(i=pytensor.scalar.basic.int64)
 
     def __str__(self):
-        return "%s{%i}" % (self.__class__.__name__, self.i)
+        return f"{self.__class__.__name__}{{{self.i}}}"
 
     def make_node(self, x):
         if not (isinstance(x, Variable) and hasattr(x.type, "ndim")):
@@ -316,7 +316,7 @@ class Shape_i(COp):
                 op=self,
                 x_pos=0,
                 x=inp[0],
-                comment=("No gradient for the shape of a matrix " "is implemented."),
+                comment="No gradient for the shape of a matrix is implemented.",
             )
         ]
 
@@ -842,13 +842,13 @@ class Reshape(COp):
 
 @_vectorize_node.register(Reshape)
 def _vectorize_reshape(op, node, x, shape):
+    from pytensor.tensor.blockwise import vectorize_node_fallback
+
     old_x, old_shape = node.inputs
     batched_ndims = x.type.ndim - old_x.type.ndim
 
     if as_tensor_variable(shape).type.ndim != 1:
-        raise NotImplementedError(
-            "It is not possible to vectorize the shape argument of Reshape"
-        )
+        return vectorize_node_fallback(op, node, x, shape)
 
     if len(tuple(old_shape)) == len(tuple(shape)):
         new_shape = [*x.shape[:batched_ndims], *shape]
